==> zio-aws-dataexchange_2.13-5.17.129.2-sources.jar: zio/aws/dataexchange/model/RedshiftDataShareAssetSourceEntry.scala <==
package zio.aws.dataexchange.model
import zio.aws.dataexchange.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class RedshiftDataShareAssetSourceEntry(dataShareArn: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.dataexchange.model.RedshiftDataShareAssetSourceEntry = {
    import RedshiftDataShareAssetSourceEntry.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.dataexchange.model.RedshiftDataShareAssetSourceEntry
      .builder()
      .dataShareArn(__string.unwrap(dataShareArn): java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.dataexchange.model.RedshiftDataShareAssetSourceEntry.ReadOnly =
    zio.aws.dataexchange.model.RedshiftDataShareAssetSourceEntry
      .wrap(buildAwsValue())
}
object RedshiftDataShareAssetSourceEntry {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.dataexchange.model.RedshiftDataShareAssetSourceEntry
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.dataexchange.model.RedshiftDataShareAssetSourceEntry =
      zio.aws.dataexchange.model.RedshiftDataShareAssetSourceEntry(dataShareArn)
    def dataShareArn: __string
    def getDataShareArn: ZIO[Any, Nothing, __string] = ZIO.succeed(dataShareArn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.dataexchange.model.RedshiftDataShareAssetSourceEntry
  ) extends zio.aws.dataexchange.model.RedshiftDataShareAssetSourceEntry.ReadOnly {
    override val dataShareArn: __string =
      zio.aws.dataexchange.model.primitives.__string(impl.dataShareArn())
  }
  def wrap(
      impl: software.amazon.awssdk.services.dataexchange.model.RedshiftDataShareAssetSourceEntry
  ): zio.aws.dataexchange.model.RedshiftDataShareAssetSourceEntry.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-dataexchange_2.13-5.17.295.2-sources.jar: zio/aws/dataexchange/model/RedshiftDataShareAssetSourceEntry.scala <==
package zio.aws.dataexchange.model
import zio.aws.dataexchange.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class RedshiftDataShareAssetSourceEntry(dataShareArn: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.dataexchange.model.RedshiftDataShareAssetSourceEntry = {
    import RedshiftDataShareAssetSourceEntry.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.dataexchange.model.RedshiftDataShareAssetSourceEntry
      .builder()
      .dataShareArn(dataShareArn: java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.dataexchange.model.RedshiftDataShareAssetSourceEntry.ReadOnly =
    zio.aws.dataexchange.model.RedshiftDataShareAssetSourceEntry
      .wrap(buildAwsValue())
}
object RedshiftDataShareAssetSourceEntry {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.dataexchange.model.RedshiftDataShareAssetSourceEntry
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.dataexchange.model.RedshiftDataShareAssetSourceEntry =
      zio.aws.dataexchange.model.RedshiftDataShareAssetSourceEntry(dataShareArn)
    def dataShareArn: __string
    def getDataShareArn: ZIO[Any, Nothing, __string] = ZIO.succeed(dataShareArn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.dataexchange.model.RedshiftDataShareAssetSourceEntry
  ) extends zio.aws.dataexchange.model.RedshiftDataShareAssetSourceEntry.ReadOnly {
    override val dataShareArn: __string = impl.dataShareArn(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.dataexchange.model.RedshiftDataShareAssetSourceEntry
  ): zio.aws.dataexchange.model.RedshiftDataShareAssetSourceEntry.ReadOnly =
    new Wrapper(impl)
}
